@@ -38,7 +38,7 @@ utcnow = arrow.utcnow
 
 
 def _create_scoped_session(db, query_cls):
-    session = sessionmaker(autoflush=False, autocommit=False,
+    session = sessionmaker(autoflush=True, autocommit=True,
                            bind=db.engine, query_cls=query_cls)
     return scoped_session(session)
 
@@ -300,7 +300,7 @@ class BaseModel(object):
         """
         try:
             self.db.add(self)
-            self.db.commit()
+            # self.db.commit()
             return self
         except Exception as e:
             self.db.rollback()
@@ -314,8 +314,8 @@ class BaseModel(object):
 
         """
         try:
-            self.db.session.delete(self)
-            return self.db.commit()
+            return self.db.session.delete(self)
+            # return self.db.commit()
         except Exception as e:
             self.db.rollback()
             raise
@@ -370,8 +370,8 @@ class Model(BaseModel):
         # Hard delete
         if hard_delete:
             try:
-                self.db.session.delete(self)
-                return self.db.commit()
+                return self.db.session.delete(self)
+                # return self.db.commit()
             except:
                 self.db.rollback()
                 raise
